#include "at32f403a_407.h"
#include "analog_output.h"
#include "shift_reg.h"
#include "utility.h"
#include "FreeRTOS.h"
#include "task.h"
#include "settings_api.h"
#include "dac_transport.h"
#include "monitoring.h"
#include "mux.h"
#include <stdio.h>

#undef DBG
#define DBG if(1)

#if defined (MAO_4)


uint16_t ao_mode;   // режим работы аналоговый

uint16_t ao_power;  // слово состояния питания выходных каналов


led_t ao_output_led[4] = {OUT_1_G, OUT_2_G, OUT_3_G, OUT_4_G};



//
void ao_init(void)
{
    // Зеленые LED сигнализируют (вкл/выкл) входов.
    ao_led_update();    
    
    // Сдвиговые регистры
    sh_init();
    
    // Внешний DAC
    dac_init();
    
#if 0    
    // Режим измерения
    ai_set_meas_mode();
    
    // Питание внешних датчиков
    ai_ext_sens_power(settings.ext_sens_power); 
    
    // Внешинй ADC
    ai_adc_init();
    
    // Modbus параметры
    ai_init_modbus_params();
#endif    
}

// Управление LED для выходов
void ao_led_update(void)
{
    for (int i = 0; i < AO_NUMBER; i++) 
    {
        if (settings.ao[i].state)
            leds[ao_output_led[i]].state = LED_ON;
        else
            leds[ao_output_led[i]].state = LED_OFF;
    }
}

// 
void ao_set(void)
{
    for (int i = 0; i < AO_NUMBER; i++) 
    {
        if (((settings.ao_state_bits >> i) & 1) != settings.ao[i].state)
        {
            settings.ao[i].state = ((settings.ao_state_bits >> i) & 1);
            if (settings.ao[i].state == 0) {
                leds[ao_output_led[i]].state = LED_OFF;
            }
            else {
                leds[ao_output_led[i]].state = LED_ON;
            }
        }
    }
}

// Установить режим работы каналов
void ao_set_mode(void)
{
    for (int i = 0; i < AO_NUMBER; i++)
    {
        settings.ao[i].mode = (uint8_t)((settings.ao_mode_bits >> i) & 1);
    }
}

// 
void dac_task(void *params)
{
    for (;;)
    {
        ao_power = sh_ao_mode(ao_mode);
        //printf("AO_Power: %u\r\n", ao_power);
        vTaskDelay(100);
#if 0        
        ai_alarm = sh_ai_mode(ai_mode);
        ai_processing();
        ai_leds_processing();
        vTaskDelay(10);
#endif        
    }
}

#endif